@@ -1,6 +1,29 @@
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
+/*
+ * Copyright (c) 2019-2020 Job Snijders <job@sobornost.net>
+ * Copyright (c) 2007-2019 Alexandre Snarskii <snar@snar.spb.ru>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
 
 #include <ctype.h>
 #include <errno.h>
@@ -12,13 +35,13 @@
 #include "sx_prefix.h"
 #include "sx_report.h"
 
-int debug_aggregation=0;
+int debug_aggregation = 0;
 extern int debug_expander;
 
 struct sx_prefix*
-sx_prefix_alloc(struct sx_prefix* p)
+sx_prefix_alloc(struct sx_prefix *p)
 {
-	struct sx_prefix* sp = malloc(sizeof(struct sx_prefix));
+	struct sx_prefix *sp = malloc(sizeof(struct sx_prefix));
 
 	if (!sp)
 		return NULL;
@@ -32,7 +55,7 @@ sx_prefix_alloc(struct sx_prefix* p)
 }
 
 void
-sx_prefix_destroy(struct sx_prefix* p)
+sx_prefix_destroy(struct sx_prefix *p)
 {
 	if (p)
 		free(p);
@@ -53,16 +76,16 @@ sx_radix_node_destroy(struct sx_radix_node *n)
 }
 
 void
-sx_prefix_adjust_masklen(struct sx_prefix* p)
+sx_prefix_adjust_masklen(struct sx_prefix *p)
 {
-	int nbytes = (p->family == AF_INET ? 4 : 16);
-	int i;
+	unsigned int	nbytes = (p->family == AF_INET ? 4 : 16);
+	unsigned int	i;
 
 	if (p->masklen == nbytes * 8)
 		return; /* mask is all ones */
 
 	for (i = nbytes -1; i > p->masklen / 8; i--) {
-		p->addr.addrs[i]=0;
+		p->addr.addrs[i] = 0;
 	}
 
 	for (i = 1; i <= 8 - p->masklen % 8; i++) {
@@ -70,10 +93,10 @@ sx_prefix_adjust_masklen(struct sx_prefix* p)
 	}
 }
 
-void
-sx_prefix_mask(struct sx_prefix* p, struct sx_prefix* q)
+static void
+sx_prefix_mask(struct sx_prefix *p, struct sx_prefix *q)
 {
-	int i;
+	unsigned int	i;
 
 	memset(q->addr.addrs, 0, sizeof(q->addr.addrs));
 
@@ -87,10 +110,10 @@ sx_prefix_mask(struct sx_prefix* p, struct sx_prefix* q)
 		q->addr.addrs[p->masklen / 8] |= (1 << (8 - i));
 }
 
-void
-sx_prefix_imask(struct sx_prefix* p, struct sx_prefix* q)
+static void
+sx_prefix_imask(struct sx_prefix *p, struct sx_prefix *q)
 {
-	int i;
+	unsigned int	i;
 
 	memset(q->addr.addrs, 0xff, sizeof(q->addr.addrs));
 
@@ -106,11 +129,11 @@ sx_prefix_imask(struct sx_prefix* p, struct sx_prefix* q)
 
 
 int
-sx_prefix_parse(struct sx_prefix* p, int af, char* text)
+sx_prefix_parse(struct sx_prefix *p, int af, char *text)
 {
-	char* c = NULL;
-	int masklen, ret;
-	char mtext[INET6_ADDRSTRLEN+5];
+	char	*c = NULL;
+	int	 masklen, ret;
+	char	 mtext[INET6_ADDRSTRLEN + 5];
 
 	strlcpy(mtext, text, sizeof(mtext));
 
@@ -119,7 +142,7 @@ sx_prefix_parse(struct sx_prefix* p, int af, char* text)
 	if (c) {
 		char* eod;
 		*c = 0;
-		masklen = strtol(c+1, &eod, 10);
+		masklen = strtol(c + 1, &eod, 10);
 		if (eod && eod[0] && !isspace(eod[0])) {
 			*c = '/';
 			sx_report(SX_ERROR, "Invalid masklen in prefix %s\n",
@@ -169,7 +192,7 @@ sx_prefix_parse(struct sx_prefix* p, int af, char* text)
 		if (masklen == -1)
 			p->masklen = 32;
 		else {
-			if(masklen < 0 || masklen > 32) {
+			if (masklen < 0 || masklen > 32) {
 				p->masklen = 32;
 			} else {
 				p->masklen = masklen;
@@ -202,10 +225,10 @@ fixups:
 	return 0;
 }
 
-int
-sx_prefix_isbitset(struct sx_prefix* p, int n)
+static int
+sx_prefix_isbitset(struct sx_prefix *p, int n)
 {
-	unsigned char s;
+	unsigned char	s;
 
 	/* bits outside the prefix considered unset */
 	if (p->family == AF_INET && (n < 0 || n > 32))
@@ -217,10 +240,10 @@ sx_prefix_isbitset(struct sx_prefix* p, int n)
 	return (s & (0x80 >> ((n - 1) % 8))) ? 1 : 0;
 }
 
-void
-sx_prefix_setbit(struct sx_prefix* p, int n)
+static void
+sx_prefix_setbit(struct sx_prefix *p, int n)
 {
-	unsigned char* s;
+	unsigned char	*s;
 
 	if (p->family == AF_INET && (n < 0 || n > 32))
 		return;
@@ -233,8 +256,8 @@ sx_prefix_setbit(struct sx_prefix* p, int n)
 }
 
 
-int
-sx_radix_tree_insert_specifics(struct sx_radix_tree* t, struct sx_prefix *p,
+static int
+sx_radix_tree_insert_specifics(struct sx_radix_tree *t, struct sx_prefix *p,
     unsigned min, unsigned max)
 {
 	struct sx_prefix *np;
@@ -258,12 +281,12 @@ sx_radix_tree_insert_specifics(struct sx_radix_tree* t, struct sx_prefix *p,
 }
 
 int
-sx_prefix_range_parse(struct sx_radix_tree* tree, int af, int maxlen,
-    char* text)
+sx_prefix_range_parse(struct sx_radix_tree *tree, int af, unsigned int maxlen,
+    char *text)
 {
-	char* d = strchr(text, '^');
-	struct sx_prefix *p;
-	unsigned long min, max;
+	char			*d = strchr(text, '^');
+	struct sx_prefix	*p;
+	unsigned long		 min, max = 0;
 
 	p = sx_prefix_alloc(NULL);
 
@@ -274,7 +297,7 @@ sx_prefix_range_parse(struct sx_radix_tree* tree, int af, int maxlen,
 
 	if (!sx_prefix_parse(p, 0, text)) {
 		sx_report(SX_ERROR, "Unable to parse prefix %s^%s\n", text,
-		    d+1);
+		    d + 1);
 		return 0;
 	}
 
@@ -299,8 +322,8 @@ sx_prefix_range_parse(struct sx_radix_tree* tree, int af, int maxlen,
 		min = p->masklen;
 		max = maxlen;
 	} else if (isdigit(d[1])) {
-		char* dm = NULL;
-		min = strtoul(d+1, &dm, 10);
+		char *dm = NULL;
+		min = strtoul(d + 1, &dm, 10);
 		if (dm && *dm == '-' && isdigit(dm[1])) {
 			max = strtoul(dm + 1, NULL, 10);
 		} else if (dm && *dm) {
@@ -340,10 +363,10 @@ sx_prefix_range_parse(struct sx_radix_tree* tree, int af, int maxlen,
 	return 1;
 }
 
-struct sx_prefix*
-sx_prefix_new(int af, char* text)
+struct sx_prefix *
+sx_prefix_new(int af, char *text)
 {
-	struct sx_prefix* p = NULL;
+	struct sx_prefix *p = NULL;
 
 	if (!text)
 		return NULL;
@@ -362,7 +385,7 @@ sx_prefix_new(int af, char* text)
 }
 
 int
-sx_prefix_fprint(FILE* f, struct sx_prefix* p)
+sx_prefix_fprint(FILE *f, struct sx_prefix *p)
 {
 	char buffer[128];
 
@@ -376,7 +399,7 @@ sx_prefix_fprint(FILE* f, struct sx_prefix* p)
 }
 
 int
-sx_prefix_snprintf_sep(struct sx_prefix* p, char* rbuffer, int srb, char* sep)
+sx_prefix_snprintf_sep(struct sx_prefix *p, char *rbuffer, int srb, char *sep)
 {
 	char buffer[128];
 
@@ -394,23 +417,22 @@ sx_prefix_snprintf_sep(struct sx_prefix* p, char* rbuffer, int srb, char* sep)
 }
 
 int
-sx_prefix_snprintf(struct sx_prefix* p, char* rbuffer, int srb)
+sx_prefix_snprintf(struct sx_prefix *p, char *rbuffer, int srb)
 {
 	return sx_prefix_snprintf_sep(p, rbuffer, srb, "/");
 }
 
 void
-sx_prefix_snprintf_fmt(struct sx_prefix* p, FILE* f,
-    const char* name, const char* format,
+sx_prefix_snprintf_fmt(struct sx_prefix *p, FILE *f,
+    const char *name, const char *format,
     unsigned int aggregateLow, unsigned int aggregateHi)
 {
-	unsigned off = 0;
-	const char* c = format;
-	struct sx_prefix *q = sx_prefix_alloc(NULL);
-	char prefix[128];
+	const char		*c = format;
+	struct sx_prefix	*q = sx_prefix_alloc(NULL);
+	char			 prefix[128];
 
 	while (*c) {
-		if(*c == '%') {
+		if (*c == '%') {
 			switch (*(c + 1)) {
 			case 'r':
 			case 'n':
@@ -461,7 +483,7 @@ sx_prefix_snprintf_fmt(struct sx_prefix* p, FILE* f,
 			}
 			c += 2;
 		} else if (*c == '\\') {
-			switch(*(c+1)) {
+			switch(*(c + 1)) {
 			case 'n':
 				fprintf(f, "\n");
 				break;
@@ -484,7 +506,7 @@ sx_prefix_snprintf_fmt(struct sx_prefix* p, FILE* f,
 }
 
 int
-sx_prefix_jsnprintf(struct sx_prefix* p, char* rbuffer, int srb)
+sx_prefix_jsnprintf(struct sx_prefix *p, char *rbuffer, int srb)
 {
 	char buffer[128];
 
@@ -500,7 +522,7 @@ sx_prefix_jsnprintf(struct sx_prefix* p, char* rbuffer, int srb)
 struct sx_radix_tree*
 sx_radix_tree_new(int af)
 {
-	struct sx_radix_tree* rt = malloc(sizeof(struct sx_radix_tree));
+	struct sx_radix_tree *rt = malloc(sizeof(struct sx_radix_tree));
 
 	if (!rt)
 		return NULL;
@@ -512,15 +534,15 @@ sx_radix_tree_new(int af)
 }
 
 int
-sx_radix_tree_empty(struct sx_radix_tree* t)
+sx_radix_tree_empty(struct sx_radix_tree *t)
 {
 	return t->head == NULL;
 }
 
 struct sx_radix_node*
-sx_radix_node_new(struct sx_prefix* prefix)
+sx_radix_node_new(struct sx_prefix *prefix)
 {
-	struct sx_radix_node* rn = malloc(sizeof(struct sx_radix_node));
+	struct sx_radix_node *rn = malloc(sizeof(struct sx_radix_node));
 
 	if (!rn)
 		return NULL;
@@ -533,20 +555,20 @@ sx_radix_node_new(struct sx_prefix* prefix)
 	return rn;
 }
 
-int
-sx_prefix_eqbits(struct sx_prefix* a, struct sx_prefix* b)
+static int
+sx_prefix_eqbits(struct sx_prefix *a, struct sx_prefix *b)
 {
-	int i;
-	int nbytes = (a->family == AF_INET ? 4 : 16);
+	unsigned int	i;
+	unsigned int	nbytes = (a->family == AF_INET ? 4 : 16);
 
 	for (i = 0; i < nbytes; i++) {
 
 		if (a->addr.addrs[i] == b->addr.addrs[i])
 			continue;
 		else {
-			int j;
+			unsigned int j;
 			for (j = 0; j < 8 && i * 8 + j <= a->masklen
-			    && i * 8 + j<= b->masklen; j++) {
+			    && i * 8 + j <= b->masklen; j++) {
 				if ((a->addr.addrs[i] & (0x80 >> j))
 				    != (b->addr.addrs[i] & (0x80 >> j)))
 					return i * 8 + j;
@@ -561,9 +583,9 @@ sx_prefix_eqbits(struct sx_prefix* a, struct sx_prefix* b)
 }
 
 struct sx_prefix*
-sx_prefix_overlay(struct sx_prefix* p, int n)
+sx_prefix_overlay(struct sx_prefix *p, int n)
 {
-	struct sx_prefix* sp = sx_prefix_alloc(p);
+	struct sx_prefix *sp = sx_prefix_alloc(p);
 	sp->masklen = n;
 	sx_prefix_adjust_masklen(sp);
 
@@ -571,7 +593,7 @@ sx_prefix_overlay(struct sx_prefix* p, int n)
 }
 
 void
-sx_radix_tree_unlink(struct sx_radix_tree* tree, struct sx_radix_node* node)
+sx_radix_tree_unlink(struct sx_radix_tree *tree, struct sx_radix_node *node)
 {
 next:
 	if (node->r && node->l)
@@ -603,14 +625,14 @@ next:
 			if (node->parent->r == node) {
 				node->parent->r = node->l;
 				node->l->parent = node->parent;
-			} else if(node->parent->l==node) {
+			} else if (node->parent->l==node) {
 				node->parent->l=node->l;
 				node->l->parent=node->parent;
 			} else {
 				sx_report(SX_ERROR,"Unlinking node which is not descendant "
 					"of its parent\n");
 			}
-		} else if(tree->head==node) {
+		} else if (tree->head==node) {
 			tree->head=node->l;
 			node->l->parent=NULL;
 		} else {
@@ -621,7 +643,7 @@ next:
 	} else {
 		/* the only case - node does not have descendants */
 		if (node->parent) {
-			if(node->parent->l == node)
+			if (node->parent->l == node)
 				node->parent->l = NULL;
 			else if (node->parent->r == node)
 				node->parent->r=NULL;
@@ -647,10 +669,10 @@ next:
 	
 			
 struct sx_radix_node*
-sx_radix_tree_lookup(struct sx_radix_tree* tree, struct sx_prefix* prefix)
+sx_radix_tree_lookup(struct sx_radix_tree *tree, struct sx_prefix *prefix)
 {
-	int eb;
-	struct sx_radix_node* candidate = NULL, *chead;
+	unsigned int 		 eb;
+	struct sx_radix_node	*candidate = NULL, *chead;
 
 	if (!tree || !prefix)
 		return NULL;
@@ -711,19 +733,19 @@ next:
 
 
 struct sx_radix_node*
-sx_radix_tree_insert(struct sx_radix_tree* tree, struct sx_prefix* prefix)
+sx_radix_tree_insert(struct sx_radix_tree *tree, struct sx_prefix *prefix)
 {
-	int eb;
-	struct sx_radix_node** candidate=NULL, *chead;
+	unsigned int		 eb;
+	struct sx_radix_node	**candidate=NULL, *chead;
 
 	if (!tree || !prefix)
 		return NULL;
 
-	if (tree->family!=prefix->family)
+	if (tree->family != prefix->family)
 		return NULL;
 
 	if (!tree->head) {
-		tree->head=sx_radix_node_new(prefix);
+		tree->head = sx_radix_node_new(prefix);
 		return tree->head;
 	}
 
@@ -735,7 +757,7 @@ next:
 	if (eb < prefix->masklen && eb < chead->prefix->masklen) {
 		struct sx_prefix *neoRoot = sx_prefix_alloc(prefix);
 		
-		struct sx_radix_node* rn, *ret=sx_radix_node_new(prefix);
+		struct sx_radix_node *rn, *ret=sx_radix_node_new(prefix);
 		neoRoot->masklen = eb;
 		sx_prefix_adjust_masklen(neoRoot);
 		rn=sx_radix_node_new(neoRoot);
@@ -762,7 +784,7 @@ next:
 		*candidate = rn;
 		return ret;
 	} else if (eb == prefix->masklen && eb < chead->prefix->masklen) {
-		struct sx_radix_node* ret = sx_radix_node_new(prefix);
+		struct sx_radix_node *ret = sx_radix_node_new(prefix);
 		if (sx_prefix_isbitset(chead->prefix, eb + 1)) {
 			ret->r = chead;
 		} else {
@@ -811,10 +833,11 @@ next:
 }
 
 void
-sx_radix_node_fprintf(struct sx_radix_node* node, void* udata)
+sx_radix_node_fprintf(struct sx_radix_node *node, void *udata)
 {
-	FILE* out = (udata?udata:stdout);
-	char buffer[128];
+	FILE	*out = (udata?udata:stdout);
+	char	 buffer[128];
+
 	if (!node) {
 		fprintf(out, "(null)\n");
 	} else {
@@ -824,10 +847,10 @@ sx_radix_node_fprintf(struct sx_radix_node* node, void* udata)
 }
 
 int
-sx_radix_node_foreach(struct sx_radix_node* node,
-    void (*func)(struct sx_radix_node*, void*), void* udata)
+sx_radix_node_foreach(struct sx_radix_node *node,
+    void (*func)(struct sx_radix_node*, void*), void *udata)
 {
-	func(node,udata);
+	func(node, udata);
 
 	if (node->l)
 		sx_radix_node_foreach(node->l, func, udata);
@@ -839,25 +862,27 @@ sx_radix_node_foreach(struct sx_radix_node* node,
 }
 
 int
-sx_radix_tree_foreach(struct sx_radix_tree* tree,
-	void (*func)(struct sx_radix_node*, void*), void* udata)
+sx_radix_tree_foreach(struct sx_radix_tree *tree,
+    void (*func)(struct sx_radix_node *, void *), void *udata)
 {
-	if(!func || !tree || !tree->head) return 0;
-	sx_radix_node_foreach(tree->head,func,udata);
+	if (!func || !tree || !tree->head)
+		return 0;
+
+	sx_radix_node_foreach(tree->head, func, udata);
 	return 0;
 }
 
-int
-sx_radix_node_aggregate(struct sx_radix_node* node)
+static int
+sx_radix_node_aggregate(struct sx_radix_node *node)
 {
-	if(node->l)
+	if (node->l)
 		sx_radix_node_aggregate(node->l);
-	if(node->r)
+	if (node->r)
 		sx_radix_node_aggregate(node->r);
 
-	if(debug_aggregation) {
+	if (debug_aggregation) {
 		printf("Aggregating on node: ");
-		sx_prefix_fprint(stdout,node->prefix);
+		sx_prefix_fprint(stdout, node->prefix);
 		printf(" %s%s%u,%u\n", node->isGlue?"Glue ":"",
 			node->isAggregate?"Aggregate ":"",node->aggregateLow,
 			node->aggregateHi);
@@ -900,7 +925,7 @@ sx_radix_node_aggregate(struct sx_radix_node* node)
 		if (!node->r->isAggregate && !node->l->isAggregate
 		    && !node->r->isGlue && !node->l->isGlue
 		    && node->r->prefix->masklen == node->l->prefix->masklen) {
-			if (node->r->prefix->masklen == node->prefix->masklen+1) {
+			if (node->r->prefix->masklen == node->prefix->masklen + 1) {
 				node->isAggregate = 1;
 				node->r->isGlue = 1;
 				node->l->isGlue = 1;
@@ -994,7 +1019,7 @@ sx_radix_node_aggregate(struct sx_radix_node* node)
 		    && node->l->aggregateHi == node->r->son->aggregateHi
 		    && node->l->aggregateLow == node->r->son->aggregateLow) {
 			if (node->l->prefix->masklen == node->prefix->masklen + 1
-			    && node->r->prefix->masklen == node->prefix->masklen+1) {
+			    && node->r->prefix->masklen == node->prefix->masklen + 1) {
 				if (node->isGlue) {
 					node->l->isGlue = 1;
 					node->r->son->isGlue = 1;
@@ -1019,7 +1044,7 @@ sx_radix_node_aggregate(struct sx_radix_node* node)
 }
 
 int
-sx_radix_tree_aggregate(struct sx_radix_tree* tree)
+sx_radix_tree_aggregate(struct sx_radix_tree *tree)
 {
 	if (tree && tree->head)
 		return sx_radix_node_aggregate(tree->head);
@@ -1028,7 +1053,7 @@ sx_radix_tree_aggregate(struct sx_radix_tree* tree)
 }
 
 static void
-setGlueUpTo(struct sx_radix_node* node, void* udata)
+setGlueUpTo(struct sx_radix_node *node, void *udata)
 {
 	unsigned refine = *(unsigned*)udata;
 
@@ -1036,8 +1061,8 @@ setGlueUpTo(struct sx_radix_node* node, void* udata)
 		node->isGlue = 1;
 }
 
-int
-sx_radix_node_refine(struct sx_radix_node* node, unsigned refine)
+static int
+sx_radix_node_refine(struct sx_radix_node *node, unsigned refine)
 {
 	if (!node->isGlue && node->prefix->masklen<refine) {
 		node->isAggregate = 1;
@@ -1079,7 +1104,7 @@ sx_radix_node_refine(struct sx_radix_node* node, unsigned refine)
 }
 	
 int
-sx_radix_tree_refine(struct sx_radix_tree* tree, unsigned refine)
+sx_radix_tree_refine(struct sx_radix_tree *tree, unsigned refine)
 {
 	if (tree && tree->head)
 		return sx_radix_node_refine(tree->head, refine);
@@ -1088,16 +1113,16 @@ sx_radix_tree_refine(struct sx_radix_tree* tree, unsigned refine)
 }
 
 static void
-setGlueFrom(struct sx_radix_node* node, void* udata)
+setGlueFrom(struct sx_radix_node *node, void *udata)
 {
 	unsigned refine = *(unsigned*)udata;
 
 	if (node && node->prefix->masklen <= refine)
-		node->isGlue=1;
+		node->isGlue = 1;
 }
 
 static int
-sx_radix_node_refineLow(struct sx_radix_node* node, unsigned refineLow)
+sx_radix_node_refineLow(struct sx_radix_node *node, unsigned refineLow)
 {
 	if (!node->isGlue && node->prefix->masklen<=refineLow) {
 
@@ -1148,7 +1173,7 @@ sx_radix_node_refineLow(struct sx_radix_node* node, unsigned refineLow)
 }
 
 int
-sx_radix_tree_refineLow(struct sx_radix_tree* tree, unsigned refineLow)
+sx_radix_tree_refineLow(struct sx_radix_tree *tree, unsigned refineLow)
 {
 	if (tree && tree->head)
 		return sx_radix_node_refineLow(tree->head, refineLow);
@@ -1159,10 +1184,10 @@ sx_radix_tree_refineLow(struct sx_radix_tree* tree, unsigned refineLow)
 #if SX_PTREE_TEST
 int
 main() {
-	struct sx_prefix* p;
-	int n;
-	struct sx_radix_tree* tree;
-	struct sx_radix_node* node;
+	struct sx_prefix	*p;
+	struct sx_radix_tree	*tree;
+	struct sx_radix_node	*node;
+	int			 n;
 
 	p = sx_prefix_new(0, "10.11.12.13/24");
 	sx_prefix_fprint(stdout, p);
@@ -1214,14 +1239,12 @@ main() {
 	sx_prefix_fprint(stdout, p);
 	printf("\n");
 
-#define SX_TEST_EBITS(a,b,susp) n = sx_prefix_eqbits(sx_prefix_new(0,a)),\
-		sx_prefix_new(0,b))); \
-		if (n != susp) \
-			printf("FAILED: %s eqbits %s=%i, not %i\n", a, b, n,
-			     susp);\
-		else
-			printf("OK, %s eqbits %s = %i, as suspected\n", a, b,
-			    n);
+#define SX_TEST_EBITS(a, b, susp) \
+	n = sx_prefix_eqbits(sx_prefix_new(0, a), sx_prefix_new(0, b)); \
+	if (n != susp) \
+		printf("FAILED: %s eqbits %s=%i, not %i\n", a, b, n, susp); \
+	else \
+		printf("OK, %s eqbits %s = %i, as suspected\n", a, b, n);
 	SX_TEST_EBITS("192.168.0.0/24", "192.168.1.0/24", 23);
 	SX_TEST_EBITS("192.168.0.0/32", "192.168.0.1/32", 31);
 #if SX_LIBPTREE_IPV6
